@@ -28,7 +28,7 @@
 
 package Config::Model::WarpedNode ;
 BEGIN {
-  $Config::Model::WarpedNode::VERSION = '1.223';
+  $Config::Model::WarpedNode::VERSION = '1.224';
 }
 
 use Carp qw(cluck croak);
@@ -50,7 +50,7 @@ Config::Model::WarpedNode - Node that change config class properties
 
 =head1 VERSION
 
-version 1.223
+version 1.224
 
 =head1 SYNOPSIS
 
@@ -244,7 +244,7 @@ get_cargo_type describe config_model
 foreach my $method (qw/fetch_element config_class_name copy_from get_element_name
                        has_element is_element_available element_type load
 		       fetch_element_value get_type get_cargo_type dump_tree
-                       describe config_model get_help/
+                       describe config_model get_help children get set/
 		   ) {
     # to register new methods in package
     no strict "refs"; 
